api.pdns.v3.test_helpers package — Argus-Toolbelt 1.0 documentation

# api.pdns.v3.test_helpers package

## Subpackages

- api.pdns.v3.test_helpers.search package
  - Submodules
  - api.pdns.v3.test_helpers.search.search_records module
  - Module contents

## Submodules

## api.pdns.v3.test_helpers.search_records_simplified module

`api.pdns.v3.test_helpers.search_records_simplified.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/pdns/v3/w+, respond with HTTP 403

`api.pdns.v3.test_helpers.search_records_simplified.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/pdns/v3/w+, respond with HTTP 404

`api.pdns.v3.test_helpers.search_records_simplified.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/pdns/v3/w+, respond with HTTP 200

`api.pdns.v3.test_helpers.search_records_simplified.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/pdns/v3/w+, respond with HTTP 401

## Module contents